@@ -353,7 +353,7 @@ def main(libsdir):
         prog='gst-validate-launcher', description=_help_message)
 
     parser.add_argument('testsuites', metavar='N', nargs='*',
-                        help="""Lets you specify a file where the testsuite to execute is defined.
+                        help="""Lets you specify a test to run, a testsuite name or a file where the testsuite to execute is defined.
 
 In the module if you want to work with a specific test manager(s) (for example,
 'ges' or 'validate'), you should define the TEST_MANAGER variable in the
@@ -464,11 +464,15 @@ Note that all testsuite should be inside python modules, so the directory should
                              " in a virtual framebuffer."
                              " Note that it is currently implemented only"
                              " for the X  server thanks to Xvfb (which is requeried in that case)")
+    parser.add_argument('--xunit-file', dest='xunit_file',
+                        action='store', metavar="FILE",
+                        help=("Path to xml file to store the xunit report in."))
+    parser.add_argument('--shuffle', dest="shuffle", action="store_true",
+                        help="Runs the test in a random order. Can help speed up the overall"
+                             " test time by running synchronized and unsynchronized tests"
+                             " at the same time")
     dir_group = parser.add_argument_group(
         "Directories and files to be used by the launcher")
-    parser.add_argument('--xunit-file', action='store',
-                        dest='xunit_file', metavar="FILE",
-                        help=("Path to xml file to store the xunit report in."))
     dir_group.add_argument("-M", "--main-dir", dest="main_dir",
                            help="Main directory where to put files. Default is %s" % DEFAULT_MAIN_DIR)
     dir_group.add_argument("--testsuites-dir", dest="testsuites_dirs", action='append',
@@ -494,6 +498,9 @@ Note that all testsuite should be inside python modules, so the directory should
                            help="Number of tests to execute simultaneously"
                            " (Defaults to number of cores of the processor)",
                            type=int)
+    dir_group.add_argument("--ignore-numfailures", dest="ignore_numfailures",
+                           help="Ignore the number of failed test in exit code",
+                           default=False, action='store_true')
 
     http_server_group = parser.add_argument_group(
         "Handle the HTTP server to be created")
@@ -595,6 +602,8 @@ Note that all testsuite should be inside python modules, so the directory should
         pass
     finally:
         res = tests_launcher.final_report()
+        if options.ignore_numfailures:
+            res = 0
         tests_launcher.clean_tests()
         httpsrv.stop()
         vfb_server.stop()
